pub(crate) fn envify(s: &str) -> StringExpand description
Converts a target-tuple or other string into the form expected by cargo environment variable names.
For example:
x86_64-unknown-linux-gnu=>X86_64_UNKNOWN_LINUX_GNU.
pub(crate) fn envify(s: &str) -> StringConverts a target-tuple or other string into the form expected by cargo environment variable names.
For example:
x86_64-unknown-linux-gnu => X86_64_UNKNOWN_LINUX_GNU.